Module item

Module item 

Set of items readers / writers (for exemple: csv reader and writer)

Modules

csvcsv
This module provides a CSV item reader and writer implementation for Spring Batch.
fakefake
This module provides a fake item reader and writer implementation for Spring Batch.
jsonjson
This module provides a JSON item reader and writer implementation for Spring Batch.
loggerlogger
This module provides a logger item reader and writer implementation for Spring Batch.
mongodbmongodb
This module provides a MongoDB item reader and writer implementation for Spring Batch.
ormorm
This module provides an ORM item reader and writer implementation for Spring Batch (SeaORM-based).
rdbcrdbc
This module provides an RDBC item reader and writer implementation for Spring Batch.
xmlxml
This module provides an XML item reader and writer implementation for Spring Batch.