Available on crate feature
json only.Expand description
This module provides a JSON item reader and writer implementation for Spring Batch.
Re-exports
pub use json_reader::JsonItemReader;pub use json_reader::JsonItemReaderBuilder;pub use json_writer::JsonItemWriter;pub use json_writer::JsonItemWriterBuilder;
Modules
- json_
reader - JSON support for reading and writing structured data.
- json_
writer - The
json_writermodule contains theJsonItemWriterstruct, which is the main entry point for writing items to a JSON data source. It implements theItemWritertrait and provides methods for serializing Rust structs into JSON and writing them to a data source.