pub struct XmlItemReader<R, I> { /* private fields */ }Available on crate feature
xml only.Expand description
A simple reader that reads items from an XML file.
This reader parses XML content and deserializes elements with a specific tag into the desired type. It handles XML attributes, nested elements, and text content.
Examples
Reading complex nested XML structures:
use spring_batch_rs::item::xml::XmlItemReaderBuilder;
use spring_batch_rs::core::item::ItemReader;
use serde::Deserialize;
use std::io::Cursor;
// Define a nested structure matching our XML format
#[derive(Debug, Deserialize)]
struct Address {
street: String,
city: String,
country: String,
}
#[derive(Debug, Deserialize)]
struct Person {
#[serde(rename = "@id")]
id: i32,
name: String,
age: i32,
address: Address,
}
// Create XML with nested elements
let xml_data = r#"
<directory>
<person id="1">
<name>Alice</name>
<age>30</age>
<address>
<street>123 Main St</street>
<city>Springfield</city>
<country>USA</country>
</address>
</person>
</directory>
"#;
// Create a reader from the XML
let cursor = Cursor::new(xml_data);
let reader = XmlItemReaderBuilder::<Person>::new()
.tag("person")
.from_reader(cursor);
// Read and verify the person with nested address
let person = reader.read().unwrap().unwrap();
assert_eq!(person.id, 1);
assert_eq!(person.name, "Alice");
assert_eq!(person.address.street, "123 Main St");
assert_eq!(person.address.city, "Springfield");
assert_eq!(person.address.country, "USA");Trait Implementations
Sourceimpl<R: Read, I: DeserializeOwned> ItemReader<I> for XmlItemReader<R, I>
impl<R: Read, I: DeserializeOwned> ItemReader<I> for XmlItemReader<R, I>
Sourcefn read(&self) -> ItemReaderResult<I>
fn read(&self) -> ItemReaderResult<I>
Reads an item from the reader. Read more