pub struct CsvItemWriterBuilder { /* private fields */ }

Implementations

source

impl CsvItemWriterBuilder

source

pub fn new() -> CsvItemWriterBuilder

source

pub fn delimiter(self, delimiter: u8) -> CsvItemWriterBuilder

source

pub fn has_headers(self, yes: bool) -> CsvItemWriterBuilder

source

pub fn from_path<R: AsRef<Path>>(self, path: R) -> CsvItemWriter<File>

source

pub fn from_writer<W: Write>(self, wtr: W) -> CsvItemWriter<W>

Serialize a single record using Serde.

Example

This shows how to serialize normal Rust structs as CSV records. The fields of the struct are used to write a header row automatically. (Writing the header row automatically can be disabled by building the CSV writer with a WriterBuilder and calling the has_headers method.)

#[derive(serde::Serialize)]
struct Row<'a> {
    city: &'a str,
    country: &'a str,
    #[serde(rename = "popcount")]
    population: u64,
}

fn example() -> Result<(), Box<dyn Error>> {
    let wtr = CsvItemWriterBuilder::new()
        .has_headers(true)
        .from_writer(vec![]);

    wtr.write(&Row {
        city: "Boston",
        country: "United States",
        population: 4628910,
    });

    wtr.write(&Row {
        city: "Concord",
        country: "United States",
        population: 42695,
    });

    Ok(())
}