Module get

Module get 

Available on crate feature s3 only.
S3 GET tasklets for downloading files and folders from Amazon S3.

Structs

S3GetFolderTasklet
A tasklet that downloads all S3 objects under a given prefix to a local folder.
S3GetFolderTaskletBuilder
Builder for S3GetFolderTasklet.
S3GetTasklet
A tasklet that downloads a single S3 object to a local file.
S3GetTaskletBuilder
Builder for S3GetTasklet.