pub struct ZipTaskletBuilder { /* private fields */ }Available on crate feature
zip only.Expand description
Builder for creating ZipTasklet instances with a fluent interface.
This builder provides a convenient way to configure ZIP tasklets with various options such as compression level, file filters, and directory structure preservation.
Examples
use spring_batch_rs::tasklet::zip::ZipTaskletBuilder;
let tasklet = ZipTaskletBuilder::new()
.source_path("./data")
.target_path("./backup.zip")
.compression_level(9)
.include_pattern("*.txt")
.exclude_pattern("*.tmp")
.preserve_structure(true)
.build()?;Implementations
Sourceimpl ZipTaskletBuilder
impl ZipTaskletBuilder
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new ZipTaskletBuilder with default settings.
Examples
use spring_batch_rs::tasklet::zip::ZipTaskletBuilder;
let builder = ZipTaskletBuilder::new();Sourcepub fn source_path<P: AsRef<Path>>(self, path: P) -> Self
pub fn source_path<P: AsRef<Path>>(self, path: P) -> Self
Sourcepub fn target_path<P: AsRef<Path>>(self, path: P) -> Self
pub fn target_path<P: AsRef<Path>>(self, path: P) -> Self
Sourcepub fn compression_level(self, level: i32) -> Self
pub fn compression_level(self, level: i32) -> Self
Sourcepub fn include_pattern<S: Into<String>>(self, pattern: S) -> Self
pub fn include_pattern<S: Into<String>>(self, pattern: S) -> Self
Sourcepub fn exclude_pattern<S: Into<String>>(self, pattern: S) -> Self
pub fn exclude_pattern<S: Into<String>>(self, pattern: S) -> Self
Sourcepub fn preserve_structure(self, preserve: bool) -> Self
pub fn preserve_structure(self, preserve: bool) -> Self
Sourcepub fn build(self) -> Result<ZipTasklet, BatchError>
pub fn build(self) -> Result<ZipTasklet, BatchError>
Builds the ZipTasklet instance.
Returns
Ok(ZipTasklet): Successfully created taskletErr(BatchError): Error if required parameters are missing or invalid
Errors
- Returns error if source_path or target_path are not set
- Returns error if source path doesn’t exist
- Returns error if target directory cannot be created